@@ -6,10 +6,7 @@ import sys, time
 import numpy as np
 from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
-try:
-    from . import cocos
-except:
-    import cocos
+from . import cocos
 
 
 def get_nearest_index(tim_eq, tarr):
