@@ -3,11 +3,7 @@ PROJECT_NAME="Equilibrium object from shotfile"
 import sys
 import numpy as np
 
-try:
-    from . import sfobj, SFREAD, parse_kwargs
-except:
-    from sfread import SFREAD
-    import sfobj, parse_kwargs
+from . import sfobj, SFREAD, parse_kwargs
 
 
 class EMPTY:
