@@ -364,7 +364,7 @@ class WW:
                 lbuf = ct.c_uint32(nitem)
                 _lbuf = ct.byref(lbuf)
                 if nitem == 1 and dattype == 5:
-                    buffer = ct.ctyp(datanp)
+                    buffer = ctyp(datanp)
                 else:
                     buffer = ctyp.from_buffer(datanp)
                 _buffer = ct.byref(buffer)
